@@ -3,6 +3,6 @@ from django.conf.urls.defaults import url, patterns
 from feedback_form import views
 
 urlpatterns = patterns('',
-    url(r'^$', views.ContactFormView.as_view(), name="contact"),
+    url(r'^$', views.ContactFormView.as_view(), name="feedback"),
 	url(r'^$', views.ContactFormView.as_view(), name="completed"),    
 )
\ No newline at end of file
